@@ -18,6 +18,16 @@ class TestJSONSchemaValidator(TestCase):
     def test_get_ref_method(self):
         pass
 
+    def test_doesn_crash_when_schema_type_is_an_array(self):
+        schema = {
+            'type': 'object',
+            'properties': {
+                'a': {'type': ['string', 'null']}
+            }
+        }
+        validator = JSONSchemaValidator(schema)
+        validator({'a': 'hello'}) # must not fail
+
     def test_only_array_and_object_allowed_in_top_level(self):
         schema = {'type': 'string'}
         validator = JSONSchemaValidator(schema)
@@ -1215,6 +1225,13 @@ class TestJSONSchemaValidator(TestCase):
         data = {'a': ''}
         validator(data)
 
+        # 7. test choices
+        schema['properties']['a']['choices'] = ['one', 'two']
+        wrong_data = {'a': 'xxx'}
+        data = {'a': 'two'}
+        self.assertRaises(JSONSchemaValidationError, validator, wrong_data)
+        validator(data)
+
     def test_validate_string_formats(self):
         # 1. email
         schema = {
@@ -1412,6 +1429,14 @@ class TestJSONSchemaValidator(TestCase):
         self.assertRaises(JSONSchemaValidationError, validator, wrong_data)
         validator(data)
 
+        # 11. test choices
+        del schema['properties']['a']['multipleOf']
+        schema['properties']['a']['choices'] = [1, 2]
+        wrong_data = {'a': 3}
+        data = {'a': 1}
+        self.assertRaises(JSONSchemaValidationError, validator, wrong_data)
+        validator(data)
+
 
     def test_validate_number_method(self):
         # 1. type (either float or int or None)
@@ -1530,3 +1555,11 @@ class TestJSONSchemaValidator(TestCase):
         validator = JSONSchemaValidator(schema)
         self.assertRaises(JSONSchemaValidationError, validator, wrong_data)
         validator(data)
+
+        # 10. test choices
+        del schema['properties']['a']['multipleOf']
+        schema['properties']['a']['choices'] = [1, 2]
+        wrong_data = {'a': 3}
+        data = {'a': 1}
+        self.assertRaises(JSONSchemaValidationError, validator, wrong_data)
+        validator(data)
